@@ -4,15 +4,11 @@
 ###############################################################################
 
 setMethod("toJSON", "integer",
-	function(x, container = TRUE, collapse = "\n  ", NA_encode = TRUE, ..., .level = 1L) {
+	function(x, container = TRUE, collapse = "\n  ", ..., .level = 1L) {
 		tmp <- as.character(x);
 
 		if(any(missings <- !is.finite(x))){
-			if(NA_encode){
-				tmp[missings] <- dQuote(tmp[missings]);
-			} else {
-				tmp[missings] <- "null";
-			}
+			tmp[missings] <- "null";
 		}		
 		
 		tmp <- paste(tmp, collapse = ", ");
