@@ -5,15 +5,11 @@
 
 
 setMethod("toJSON", "logical",
-	function(x, container = TRUE, collapse = "\n", NA_encode = TRUE, ..., .level = 1L) {
+	function(x, container = TRUE, collapse = "\n", ..., .level = 1L) {
 		tmp = ifelse(x, "true", "false");
 
 		if(any(missings <- !is.finite(x))){
-			if(NA_encode){
-				tmp[missings] <- dQuote(tmp[missings]);
-			} else {
-				tmp[missings] <- "null";
-			}
+			tmp[missings] <- "null";
 		}		
 
 		if(container) {
